@@ -44,6 +44,7 @@
 #include "call-stream.h"
 
 #include <telepathy-glib/telepathy-glib.h>
+#include <telepathy-glib/telepathy-glib-dbus.h>
 #include <telepathy-glib/proxy-subclass.h>
 #include <farstream/fs-conference.h>
 
@@ -306,6 +307,10 @@ _tf_call_stream_push_remote_candidates (TfCallStream *self,
   gboolean ret;
   GError *error = NULL;
 
+  /* If there are no candidates, nothing to do, just return */
+  if (fscandidates == NULL)
+    return;
+
   switch (self->transport_type)
     {
     case TP_STREAM_TRANSPORT_TYPE_RAW_UDP:
@@ -1531,7 +1536,7 @@ static void
 cb_fs_component_state_changed (TfCallStream *stream, guint component,
     FsStreamState fsstate)
 {
-  TpMediaStreamState state;
+  TpStreamEndpointState state;
 
   if (!stream->endpoint)
     return;
